### Contexto
(*las líneas entre paréntesis son informativas y deberán borrarse al crear el ticket*)

(*describir muy brevemente el contexto de partida de la tarea*)
(*con la óptica de una persona que acaba de empezar a trabajar en el proyecto*)

- el proyecto `nanocore` necesita xxx para yyy 
- dato de contexto 2
- dato de contexto 3

### Tareas
(*describir brevemente cada una de las microtareas en las que la persona que ha descrito el ticket le gustaría ver como avanza el ticket*)

(*es posible ir marcando desde la web cuando cada una de estas microtareas se ha hecho, notificando a los interesados, y alimentando el histórico del ticket*)

(*es posible reordenarlos posteriormente si se considera necesario, o editar el ticket y añadir alguna microtarea más*)

(*si al analizar la tarea y hacer su breakdown, se observa que las microtareas son demasiado amplias, entonces crear sub-tareas asociadas*)

- [ ] hacer xxx
- [ ] hacer yyy

### Resultados
(*describir como el creador del ticket piensa que deberá reflejarse el resultado final*)
(*deberá ser suficiente como para que un tercero pueda verificar que está correctamente realizada*)

- [ ] commit xxx
- [ ] wiki yyy

